Data.CQRS
Description
CQRS module. This module exports all the data types and functions needed for typical CQRS applications.
Documentation
module Data.CQRS.AggregateRef
module Data.CQRS.Event
module Data.CQRS.GUID
module Data.CQRS.Transaction
cqrs-0.1.0: Command-Query Responsibility Segregation
Data.CQRS
Description
CQRS module. This module exports all the data types and functions needed for typical CQRS applications.
module Data.CQRS.AggregateRef
module Data.CQRS.Event
module Data.CQRS.GUID
module Data.CQRS.Transaction